@@ -24,20 +24,21 @@ RFSC_61 = "RFSC-61"
 RFTI_10B = "RFTI-10B"
 RFDAC_71B = "RFDAC-71B"
 RFJA_12 = "RFJA-12"
-RFATV_1 = "RFATV-1"
+RFATV_2 = "RFATV-2"
 
 INELS_DEVICE_TYPE_DICT = {
     "02": RFSC_61,
     "10": RFTI_10B,
     "05": RFDAC_71B,
     "03": RFJA_12,
-    "09": RFATV_1,
+    "09": RFATV_2,
 }
 
 BATTERY = "battery"
 TEMP_IN = "temp_in"
 TEMP_OUT = "temp_out"
 CURRENT_TEMP = "current_temp"
+REQUIRED_TEMP = "required_temp"
 OPEN_IN_PERCENTAGE = "open_in_percentage"
 RAMP_UP = "ramp_up"  # náběh
 TIME_RAMP_UP = "time_ramp"  # časový náběh
@@ -114,7 +115,12 @@ TEMP_SENSOR_DATA = {BATTERY: [0], TEMP_IN: [2, 1], TEMP_OUT: [4, 3]}
 
 SHUTTER_TYPE_03_DATA = {RFJA_12: [1]}
 
-CLIMATE_TYPE_09_DATA = {OPEN_IN_PERCENTAGE: [0], CURRENT_TEMP: [1], BATTERY: [3]}
+CLIMATE_TYPE_09_DATA = {
+    OPEN_IN_PERCENTAGE: [0],
+    CURRENT_TEMP: [1],
+    BATTERY: [2],
+    REQUIRED_TEMP: [3],
+}
 
 DISCOVERY_TIMEOUT_IN_SEC = 5
 
